@@ -1,4 +1,7 @@
 #!/bin/sh
+#
+# SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+# SPDX-License-Identifier: BSD-2-Clause
 
 set -e
 
@@ -10,7 +13,7 @@ srcdir="$(dirname -- "$testdir")"
 tgtdir='/opt/remrun-src'
 envdir='/opt/remrun-venv-run-sshd-test'
 
-distro="${1:-bullseye}"
+distro="${1:-bookworm}"
 
 docker run --rm -it -v "$srcdir:$tgtdir:ro" -- "remrun/sshd:$distro" env "PYTHONPATH=$tgtdir/tests/python" "$envdir/bin/python3" -m run_sshd_test -v "$tgtdir/remrun.sh"
 
