@@ -1,26 +1,5 @@
-# Copyright (c) 2022  Peter Pentchev <roam@ringlet.net>
-# All rights reserved.
-#
-# Redistribution and use in source and binary forms, with or without
-# modification, are permitted provided that the following conditions
-# are met:
-# 1. Redistributions of source code must retain the above copyright
-#    notice, this list of conditions and the following disclaimer.
-# 2. Redistributions in binary form must reproduce the above copyright
-#    notice, this list of conditions and the following disclaimer in the
-#    documentation and/or other materials provided with the distribution.
-#
-# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-# SUCH DAMAGE.
+# SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
+# SPDX-License-Identifier: BSD-2-Clause
 """Build a Docker container for the specified Linux distribution."""
 
 from __future__ import annotations
@@ -29,12 +8,17 @@ import argparse
 import dataclasses
 import pathlib
 import shlex
-import subprocess
+import subprocess  # noqa: S404
 import sys
 import tempfile
+import typing
 
-import cfg_diag
-import utf8_locale
+from run_sshd_test import util
+
+
+if typing.TYPE_CHECKING:
+    import logging
+    from typing import Final
 
 
 @dataclasses.dataclass(frozen=True)
@@ -48,9 +32,10 @@ class Distro:
 
 
 @dataclasses.dataclass(frozen=True)
-class Config(cfg_diag.Config):
+class Config:
     """Runtime configuration for the build_container tool."""
 
+    log: logging.Logger
     distro: Distro
     noop: bool
     pull: bool
@@ -58,34 +43,24 @@ class Config(cfg_diag.Config):
     utf8_env: dict[str, str]
 
 
-DISTROS = [
+DISTROS: Final = [
     Distro(name="unstable", distro="debian", version="unstable", pkg_system="apt"),
-    Distro(name="bullseye", distro="debian", version="bullseye", pkg_system="apt"),
-    Distro(name="buster", distro="debian", version="buster", pkg_system="apt"),
+    Distro(name="bookworm", distro="debian", version="bookworm", pkg_system="apt"),
+    Distro(name="noble", distro="ubuntu", version="noble", pkg_system="apt"),
     Distro(name="jammy", distro="ubuntu", version="jammy", pkg_system="apt"),
-    Distro(name="focal", distro="ubuntu", version="focal", pkg_system="apt"),
     Distro(
         name="centos9",
         distro="quay.io/centos/centos",
         version="stream9",
         pkg_system="yum",
     ),
-    Distro(
-        name="centos8",
-        distro="quay.io/centos/centos",
-        version="stream8",
-        pkg_system="yum",
-    ),
-    Distro(name="alma8", distro="almalinux/almalinux", version="8", pkg_system="yum"),
-    Distro(
-        name="rocky8", distro="rockylinux/rockylinux", version="8", pkg_system="yum"
-    ),
+    Distro(name="rocky9", distro="rockylinux/rockylinux", version="9", pkg_system="yum"),
 ]
 
 
 def parse_args() -> Config:
     """Parse the command-line arguments."""
-    parser = argparse.ArgumentParser(prog="build_container")
+    parser: Final = argparse.ArgumentParser(prog="build_container")
     parser.add_argument(
         "-N",
         "--noop",
@@ -93,7 +68,10 @@ def parse_args() -> Config:
         help="no-operation mode; display what would be done",
     )
     parser.add_argument(
-        "-P", "--pull", action="store_true", help="pull a newer base image if available"
+        "-P",
+        "--pull",
+        action="store_true",
+        help="pull a newer base image if available",
     )
     parser.add_argument(
         "-T",
@@ -114,7 +92,7 @@ def parse_args() -> Config:
         help="the Linux distribution to build a container for, or 'list'",
     )
 
-    args = parser.parse_args()
+    args: Final = parser.parse_args()
 
     if args.distro == "list":
         for item in DISTROS:
@@ -122,12 +100,12 @@ def parse_args() -> Config:
         sys.exit(0)
 
     return Config(
+        log=util.build_logger(name="build_container", verbose=args.verbose, quiet=False),
         distro=next(item for item in DISTROS if item.name == args.distro),
         noop=args.noop,
         pull=args.pull,
         run_test=args.run_test,
-        utf8_env=utf8_locale.UTF8Detect().detect().env,
-        verbose=args.verbose,
+        utf8_env=util.get_utf8_env(),
     )
 
 
@@ -161,30 +139,36 @@ def get_test_command(cfg: Config) -> list[str]:
 
 def run_command(cfg: Config, cmd: list[str]) -> None:
     """Run a command or, in no-op mode, display it."""
-    cmd_str = " ".join(shlex.quote(word) for word in cmd)
+    cmd_str: Final = shlex.join(cmd)
     if cfg.noop:
         print(cmd_str)
         return
 
-    cfg.diag(lambda: f"Running `{cmd_str}`")
-    subprocess.check_call(cmd, env=cfg.utf8_env)
+    cfg.log.debug("Running `%(cmd_str)s`", {"cmd_str": cmd_str})
+    subprocess.check_call(cmd, env=cfg.utf8_env)  # noqa: S603
 
 
 def copy_files(cfg: Config, tempd: pathlib.Path) -> None:
     """Copy the necessary files for building the container."""
-    flist = subprocess.check_output(
-        ["git", "ls-files", "-z", "docker"], encoding="UTF-8", env=cfg.utf8_env
-    ).strip("\0").split("\0") + ["requirements.txt"]
-    cmd = ["cp", "-p", "-v", "--"] + flist + [str(tempd)]
+    flist: Final = (
+        subprocess.check_output(  # noqa: S603
+            ["git", "ls-files", "-z", "docker"],  # noqa: S607
+            encoding="UTF-8",
+            env=cfg.utf8_env,
+        )
+        .strip("\0")
+        .split("\0")
+    )
+    cmd: Final = ["cp", "-p", "-v", "--", *flist, "requirements/install.txt", str(tempd)]
     run_command(cfg, cmd)
 
 
 def main() -> None:
-    """Main program: parse command-line options, run 'docker build'."""
-    cfg = parse_args()
+    """Parse command-line options, run 'docker build'."""
+    cfg: Final = parse_args()
 
     with tempfile.TemporaryDirectory(prefix="remrun-docker-build.") as tempd_obj:
-        tempd = pathlib.Path(tempd_obj).absolute()
+        tempd: Final = pathlib.Path(tempd_obj).absolute()
         copy_files(cfg, tempd)
         run_command(cfg, get_build_command(cfg, tempd))
 
